@@ -96,7 +96,7 @@ undefined (the default) - the result is returned as a string.
 =item * output_type (DEFAULT: 'png')
 
 This determines which
-L<output method|GraphViz/as_canon,_as_text,_as_gif_etc._methods>
+L<output method|GraphViz/as_canon, as_text, as_gif etc. methods>
 will be invoked to generate the graph: C<png> translates to
 C<as_png>, C<ps> to C<as_ps> and so on.
 
@@ -230,7 +230,7 @@ use SQL::Translator::Utils qw(debug);
 use Scalar::Util qw/openhandle/;
 
 our $DEBUG;
-our $VERSION = '1.59';
+our $VERSION = '1.6_3';
 $DEBUG   = 0 unless defined $DEBUG;
 
 sub produce {
@@ -520,7 +520,7 @@ sub produce {
 
         debug("Processing table '$table_name'");
 
-        debug("Fields = ", join(', ', map { $_->name } @fields));
+        debug("Fields = ", join(', ', map { $_->name } @fields)) if $DEBUG;
 
         for my $f ( @fields ) {
             my $name      = $f->name or next;
