@@ -21,7 +21,7 @@ takes a long time.
 
 use strict;
 use warnings;
-our $VERSION = '1.59';
+our $VERSION = '1.6_3';
 
 use YAML qw(Dump);
 
@@ -173,7 +173,7 @@ sub view_index {
     return {
         'name'      => scalar $index->name,
         'type'      => scalar $index->type,
-        'fields'    => scalar $index->fields,
+        'fields'    => [ map { ref($_) ? $_->name : $_ } $index->fields ],
         'options'   => scalar $index->options,
         keys %{$index->extra} ? ('extra' => { $index->extra } ) : (),
     };
