@@ -8,19 +8,20 @@ use Scalar::Util qw(blessed);
 use Try::Tiny;
 use Carp qw(carp croak);
 
-our $VERSION = '1.59';
-our $DEFAULT_COMMENT = '-- ';
+our $VERSION = '1.6_3';
 
 use base qw(Exporter);
 our @EXPORT_OK = qw(
     debug normalize_name header_comment parse_list_arg truncate_id_uniquely
     $DEFAULT_COMMENT parse_mysql_version parse_dbms_version
     ddl_parser_instance batch_alter_table_statements
-    throw ex2err carp_ro
+    uniq throw ex2err carp_ro
     normalize_quote_options
 );
 use constant COLLISION_TAG_LENGTH => 8;
 
+our $DEFAULT_COMMENT = '--';
+
 sub debug {
     my ($pkg, $file, $line, $sub) = caller(0);
     {
@@ -111,14 +112,14 @@ sub header_comment {
 
     my $header_comment =<<"HEADER_COMMENT";
 ${comment_char}
-${comment_char}Created by $producer
-${comment_char}Created on $now
+${comment_char} Created by $producer
+${comment_char} Created on $now
 ${comment_char}
 HEADER_COMMENT
 
     # Any additional stuff passed in
     for my $additional_comment (@_) {
-        $header_comment .= "${comment_char}${additional_comment}\n";
+        $header_comment .= "${comment_char} ${additional_comment}\n";
     }
 
     return $header_comment;
@@ -366,6 +367,15 @@ sub _find_co_root {
     }
 }
 
+sub uniq {
+  my( %seen, $seen_undef, $numeric_preserving_copy );
+  grep { not (
+    defined $_
+      ? $seen{ $numeric_preserving_copy = $_ }++
+      : $seen_undef++
+  ) } @_;
+}
+
 sub throw {
     die SQL::Translator::Utils::Error->new($_[0]);
 }
@@ -538,7 +548,7 @@ Will give three different results; specifically:
 
 =head2 $DEFAULT_COMMENT
 
-This is the default comment string, '-- ' by default.  Useful for
+This is the default comment string, '--' by default.  Useful for
 C<header_comment>.
 
 =head2 parse_mysql_version
